@@ -1,6 +1,6 @@
 package DNS::Oterica::Role::RecordMaker;
 # ABSTRACT: a delegation class for the DNSO recordmaker.
-$DNS::Oterica::Role::RecordMaker::VERSION = '0.304';
+$DNS::Oterica::Role::RecordMaker::VERSION = '0.311';
 use Moose::Role;
 
 use DNS::Oterica::RecordMaker::TinyDNS;
@@ -18,8 +18,8 @@ use DNS::Oterica::RecordMaker::TinyDNS;
 
 has rec => (
   is  => 'ro',
-  isa => 'Str', # XXX or object doing role, etc
-  default => 'DNS::Oterica::RecordMaker::TinyDNS',
+  isa => 'Defined', # String or object (duck type this?)
+  default => sub { DNS::Oterica::RecordMaker::TinyDNS->new },
 );
 
 no Moose::Role;
@@ -37,7 +37,7 @@ DNS::Oterica::Role::RecordMaker - a delegation class for the DNSO recordmaker.
 
 =head1 VERSION
 
-version 0.304
+version 0.311
 
 =head1 DESCRIPTION
 
@@ -56,7 +56,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2018 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
